---
name: r.in.png
description: Imports non-georeferenced PNG format image.
keywords: [ raster, import, PNG ]
---

# r.in.png

Imports non-georeferenced PNG format image.

=== "Command line"

    **r.in.png**
    [**-fh**]
    **input**=*name*
    **output**=*name*
    [**title**=*string*]
    [**gamma**=*float*]
    [**alpha**=*float*]
    [**--overwrite**]
    [**--verbose**]
    [**--quiet**]
    [**--qq**]
    [**--ui**]

    Example:

    ```sh
    r.in.png input=name output=name
    ```

=== "Python (grass.script)"

    *grass.script.run_command*("***r.in.png***",
        **input**,
        **output**,
        **title**=*None*,
        **gamma**=*None*,
        **alpha**=*None*,
        **flags**=*None*,
        **overwrite**=*False*,
        **verbose**=*False*,
        **quiet**=*False*,
        **superquiet**=*False*)

    Example:

    ```python
    gs.run_command("r.in.png", input="name", output="name")
    ```

## Parameters

=== "Command line"

    **input**=*name* **[required]**  
    &nbsp;&nbsp;&nbsp;&nbsp;Name of input file  
    **output**=*name* **[required]**  
    &nbsp;&nbsp;&nbsp;&nbsp;Name for output raster map  
    **title**=*string*  
    &nbsp;&nbsp;&nbsp;&nbsp;Title for created raster map  
    **gamma**=*float*  
    &nbsp;&nbsp;&nbsp;&nbsp;Display gamma  
    **alpha**=*float*  
    &nbsp;&nbsp;&nbsp;&nbsp;Alpha threshold  
    **-f**  
    &nbsp;&nbsp;&nbsp;&nbsp;Create floating-point map (0.0 - 1.0)  
    **-h**  
    &nbsp;&nbsp;&nbsp;&nbsp;Output image file header only and exit  
    **--overwrite**  
    &nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
    **--help**  
    &nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
    **--verbose**  
    &nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
    **--quiet**  
    &nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
    **--qq**  
    &nbsp;&nbsp;&nbsp;&nbsp;Very quiet module output  
    **--ui**  
    &nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

=== "Python (grass.script)"

    **input** : str, *required*  
    &nbsp;&nbsp;&nbsp;&nbsp;Name of input file  
    &nbsp;&nbsp;&nbsp;&nbsp;Used as: input, file, *name*  
    **output** : str, *required*  
    &nbsp;&nbsp;&nbsp;&nbsp;Name for output raster map  
    &nbsp;&nbsp;&nbsp;&nbsp;Used as: output, raster, *name*  
    **title** : str, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Title for created raster map  
    **gamma** : float, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Display gamma  
    **alpha** : float, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Alpha threshold  
    **flags** : str, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Allowed values: *f*, *h*  
    &nbsp;&nbsp;&nbsp;&nbsp;**f**  
    &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Create floating-point map (0.0 - 1.0)  
    &nbsp;&nbsp;&nbsp;&nbsp;**h**  
    &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Output image file header only and exit  
    **overwrite**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **verbose**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **quiet**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **superquiet**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Very quiet module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*

## DESCRIPTION

*r.in.png* imports a non-georeferenced Portable Network Graphics (PNG)
image as a GRASS raster map. Georeferencing .wld files are not
supported, for that *r.import* can be used.

## NOTES

In order to assign georeferencing after import use *r.region*.

## SEE ALSO

*[r.import](r.import.md), [r.in.gdal](r.in.gdal.md),
[r.out.png](r.out.png.md), [r.region](r.region.md)*

## AUTHORS

Michael Shapiro  
Alex Shevlakov  
Glynn Clements

## SOURCE CODE

Available at: [r.in.png source code](https://github.com/OSGeo/grass/tree/main/raster/r.in.png)
([history](https://github.com/OSGeo/grass/commits/main/raster/r.in.png))  
Latest change: Friday Feb 07 19:16:09 2025 in commit [a82a39f](https://github.com/OSGeo/grass/commit/a82a39f673b97fafcfce1604dc3e6015cb96487a)
