---
name: r3.gradient
description: Computes gradient of a 3D raster map and outputs gradient components as three 3D raster maps.
keywords: [ raster3d, gradient, voxel ]
---

# r3.gradient

Computes gradient of a 3D raster map and outputs gradient components as three 3D raster maps.

=== "Command line"

    **r3.gradient**
    **input**=*name*
    **output**=*grad_x,grad_y,grad_z* [,*grad_x,grad_y,grad_z*,...]
    [**blocksize**=*size_x,size_y,size_z* [,*size_x,size_y,size_z*,...]]
    [**--overwrite**]
    [**--verbose**]
    [**--quiet**]
    [**--qq**]
    [**--ui**]

    Example:

    ```sh
    r3.gradient input=name output=grad_x,grad_y,grad_z
    ```

=== "Python (grass.script)"

    *grass.script.run_command*("***r3.gradient***",
        **input**,
        **output**,
        **blocksize**=*"30,30,20"*,
        **overwrite**=*False*,
        **verbose**=*False*,
        **quiet**=*False*,
        **superquiet**=*False*)

    Example:

    ```python
    gs.run_command("r3.gradient", input="name", output="grad_x,grad_y,grad_z")
    ```

## Parameters

=== "Command line"

    **input**=*name* **[required]**  
    &nbsp;&nbsp;&nbsp;&nbsp;Name of input 3D raster map  
    **output**=*grad_x,grad_y,grad_z* [,*grad_x,grad_y,grad_z*,...] **[required]**  
    &nbsp;&nbsp;&nbsp;&nbsp;Name for output 3D raster map(s)  
    **blocksize**=*size_x,size_y,size_z* [,*size_x,size_y,size_z*,...]  
    &nbsp;&nbsp;&nbsp;&nbsp;Size of blocks  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *30,30,20*  
    **--overwrite**  
    &nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
    **--help**  
    &nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
    **--verbose**  
    &nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
    **--quiet**  
    &nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
    **--qq**  
    &nbsp;&nbsp;&nbsp;&nbsp;Very quiet module output  
    **--ui**  
    &nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

=== "Python (grass.script)"

    **input** : str, *required*  
    &nbsp;&nbsp;&nbsp;&nbsp;Name of input 3D raster map  
    &nbsp;&nbsp;&nbsp;&nbsp;Used as: input, raster_3d, *name*  
    **output** : list[tuple[str, str, str]] | tuple[str, str, str] | list[str] | str, *required*  
    &nbsp;&nbsp;&nbsp;&nbsp;Name for output 3D raster map(s)  
    &nbsp;&nbsp;&nbsp;&nbsp;Used as: output, raster_3d, *grad_x,grad_y,grad_z*  
    **blocksize** : list[tuple[str, str, str]] | tuple[str, str, str] | list[str] | str, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Size of blocks  
    &nbsp;&nbsp;&nbsp;&nbsp;Used as: *size_x,size_y,size_z*  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *30,30,20*  
    **overwrite**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **verbose**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **quiet**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **superquiet**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Very quiet module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*

## DESCRIPTION

Module *r3.gradient* computes gradient from a 3D raster map. Results are
three 3D raster maps describing the x, y, z components of the computed
gradient field.

## EXAMPLES

```sh
# create a 3D raster
g.region s=0 n=100 w=0 e=100 b=0 t=100 -p
r3.mapcalc "test_gradient = sqrt(row()*row() +col()*col()+ depth()*depth())"

# compute gradient
r3.gradient input=test_gradient output=grad_x,grad_y,grad_z
```

## SEE ALSO

*[r3.flow](r3.flow.md), [r.flow](r.flow.md)*

## AUTHOR

Anna Petrasova, [NCSU GeoForAll
Lab](https://geospatial.ncsu.edu/geoforall/), developed during GSoC
2014.

## SOURCE CODE

Available at: [r3.gradient source code](https://github.com/OSGeo/grass/tree/main/raster3d/r3.gradient)
([history](https://github.com/OSGeo/grass/commits/main/raster3d/r3.gradient))  
Latest change: Thursday Feb 27 06:05:37 2025 in commit [49a2352](https://github.com/OSGeo/grass/commit/49a235285f31f0ba428cdce25ff32799e7193f55)
